@@ -7,7 +7,7 @@ namespace Icinga\Module\Kubernetes\Controllers;
 use Icinga\Module\Kubernetes\Common\Auth;
 use Icinga\Module\Kubernetes\Common\Database;
 use Icinga\Module\Kubernetes\Model\Job;
-use Icinga\Module\Kubernetes\Web\ListController;
+use Icinga\Module\Kubernetes\Web\Controller\ListController;
 use ipl\Orm\Query;
 
 class JobsController extends ListController
