@@ -7,7 +7,7 @@ namespace Icinga\Module\Kubernetes\Controllers;
 use Icinga\Module\Kubernetes\Common\Auth;
 use Icinga\Module\Kubernetes\Common\Database;
 use Icinga\Module\Kubernetes\Model\NamespaceModel;
-use Icinga\Module\Kubernetes\Web\ListController;
+use Icinga\Module\Kubernetes\Web\Controller\ListController;
 use ipl\Orm\Query;
 
 class NamespacesController extends ListController
@@ -20,8 +20,8 @@ class NamespacesController extends ListController
     protected function getSortColumns(): array
     {
         return [
-            'namespaces.created desc' => $this->translate('Created'),
-            'namespaces.name'         => $this->translate('Name')
+            'namespace.created desc' => $this->translate('Created'),
+            'namespace.name'         => $this->translate('Name')
         ];
     }
 
