@@ -100,7 +100,6 @@ class PrometheusConfigForm extends CompatForm
             KConfig::transformKeyForForm(KConfig::PROMETHEUS_URL),
             [
                 'label'    => $this->translate('URL'),
-                'required' => true,
                 'value'    => $kconfig[KConfig::PROMETHEUS_URL]->value ?? null,
                 'disabled' => $kconfig[KConfig::PROMETHEUS_URL]->locked ?? false,
                 'ignore'   => $kconfig[KConfig::PROMETHEUS_URL]->locked ?? false,
@@ -114,7 +113,7 @@ class PrometheusConfigForm extends CompatForm
                 'label'          => $this->translate('Insecure'),
                 'checkedValue'   => 'true',
                 'uncheckedValue' => 'false',
-                'value'          => $kconfig[KConfig::PROMETHEUS_INSECURE]?->value === 'true',
+                'value'          => $kconfig[KConfig::PROMETHEUS_INSECURE]->value ?? null === 'true',
                 'disabled'       => $kconfig[KConfig::PROMETHEUS_INSECURE]->locked ?? false,
                 'ignore'         => $kconfig[KConfig::PROMETHEUS_INSECURE]->locked ?? false,
             ]
